@@ -28,6 +28,7 @@ from .literals import (
 from .type_defs import (
     BatchCreateChannelMembershipResponseTypeDef,
     ChannelFlowCallbackResponseTypeDef,
+    ChannelMembershipPreferencesTypeDef,
     ChannelMessageCallbackTypeDef,
     CreateChannelBanResponseTypeDef,
     CreateChannelFlowResponseTypeDef,
@@ -41,6 +42,7 @@ from .type_defs import (
     DescribeChannelModeratedByAppInstanceUserResponseTypeDef,
     DescribeChannelModeratorResponseTypeDef,
     DescribeChannelResponseTypeDef,
+    GetChannelMembershipPreferencesResponseTypeDef,
     GetChannelMessageResponseTypeDef,
     GetChannelMessageStatusResponseTypeDef,
     GetMessagingSessionEndpointResponseTypeDef,
@@ -54,7 +56,10 @@ from .type_defs import (
     ListChannelsModeratedByAppInstanceUserResponseTypeDef,
     ListChannelsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
+    MessageAttributeValueTypeDef,
     ProcessorTypeDef,
+    PushNotificationConfigurationTypeDef,
+    PutChannelMembershipPreferencesResponseTypeDef,
     RedactChannelMessageResponseTypeDef,
     SendChannelMessageResponseTypeDef,
     TagTypeDef,
@@ -90,7 +95,7 @@ class Exceptions:
 
 class ChimeSDKMessagingClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html)
     """
 
@@ -108,7 +113,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Associates a channel flow with a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.associate_channel_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.associate_channel_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#associate_channel_flow)
         """
 
@@ -123,7 +128,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Adds a specified number of users to a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.batch_create_channel_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.batch_create_channel_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#batch_create_channel_membership)
         """
 
@@ -131,7 +136,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#can_paginate)
         """
 
@@ -146,7 +151,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Calls back Chime SDK Messaging with a processing response message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.channel_flow_callback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.channel_flow_callback)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#channel_flow_callback)
         """
 
@@ -165,7 +170,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Creates a channel to which you can add users and send messages.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#create_channel)
         """
 
@@ -175,7 +180,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Permanently bans a member from a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_ban)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_ban)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#create_channel_ban)
         """
 
@@ -191,7 +196,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Creates a channel flow, a container for processors.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#create_channel_flow)
         """
 
@@ -201,7 +206,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Adds a user to a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#create_channel_membership)
         """
 
@@ -211,7 +216,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Creates a new `ChannelModerator`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_moderator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.create_channel_moderator)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#create_channel_moderator)
         """
 
@@ -220,7 +225,7 @@ class ChimeSDKMessagingClient(BaseClient):
         Immediately makes a channel and its memberships inaccessible and marks them for
         deletion.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel)
         """
 
@@ -228,7 +233,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Removes a user from a channel's ban list.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_ban)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_ban)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel_ban)
         """
 
@@ -236,7 +241,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Deletes a channel flow, an irreversible process.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel_flow)
         """
 
@@ -246,7 +251,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Removes a member from a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel_membership)
         """
 
@@ -254,7 +259,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Deletes a channel message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel_message)
         """
 
@@ -264,7 +269,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Deletes a channel moderator.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_moderator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.delete_channel_moderator)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#delete_channel_moderator)
         """
 
@@ -274,7 +279,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Returns the full details of a channel in an Amazon Chime `AppInstance` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel)
         """
 
@@ -284,7 +289,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Returns the full details of a channel ban.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_ban)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_ban)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_ban)
         """
 
@@ -292,7 +297,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Returns the full details of a channel flow in an Amazon Chime `AppInstance`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_flow)
         """
 
@@ -302,7 +307,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Returns the full details of a user's channel membership.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_membership)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_membership)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_membership)
         """
 
@@ -313,7 +318,7 @@ class ChimeSDKMessagingClient(BaseClient):
         Returns the details of a channel based on the membership of the specified
         `AppInstanceUser` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_membership_for_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_membership_for_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_membership_for_app_instance_user)
         """
 
@@ -324,7 +329,7 @@ class ChimeSDKMessagingClient(BaseClient):
         Returns the full details of a channel moderated by the specified
         `AppInstanceUser` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_moderated_by_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_moderated_by_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_moderated_by_app_instance_user)
         """
 
@@ -334,7 +339,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Returns the full details of a single ChannelModerator.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_moderator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.describe_channel_moderator)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#describe_channel_moderator)
         """
 
@@ -344,7 +349,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Disassociates a channel flow from all its channels.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.disassociate_channel_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.disassociate_channel_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#disassociate_channel_flow)
         """
 
@@ -358,17 +363,28 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#generate_presigned_url)
         """
 
+    def get_channel_membership_preferences(
+        self, *, ChannelArn: str, MemberArn: str, ChimeBearer: str
+    ) -> GetChannelMembershipPreferencesResponseTypeDef:
+        """
+        Gets the membership preferences of an `AppInstanceUser` for the specified
+        channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_channel_membership_preferences)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#get_channel_membership_preferences)
+        """
+
     def get_channel_message(
         self, *, ChannelArn: str, MessageId: str, ChimeBearer: str
     ) -> GetChannelMessageResponseTypeDef:
         """
         Gets the full details of a channel message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_channel_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_channel_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#get_channel_message)
         """
 
@@ -378,7 +394,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Gets message status for a specified `messageId`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_channel_message_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_channel_message_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#get_channel_message_status)
         """
 
@@ -386,7 +402,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         The details of the endpoint for the messaging session.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_messaging_session_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.get_messaging_session_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#get_messaging_session_endpoint)
         """
 
@@ -396,7 +412,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all the users banned from a particular channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_bans)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_bans)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_bans)
         """
 
@@ -406,7 +422,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Returns a paginated lists of all the channel flows created under a single Chime.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_flows)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_flows)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_flows)
         """
 
@@ -422,7 +438,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all channel memberships in a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_memberships)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_memberships)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_memberships)
         """
 
@@ -437,7 +453,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all channels that a particular `AppInstanceUser` is a part of.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_memberships_for_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_memberships_for_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_memberships_for_app_instance_user)
         """
 
@@ -455,7 +471,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         List all the messages in a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_messages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_messages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_messages)
         """
 
@@ -465,7 +481,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all the moderators for a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_moderators)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channel_moderators)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channel_moderators)
         """
 
@@ -481,7 +497,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all Channels created under a single Chime App as a paginated list.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channels)
         """
 
@@ -491,7 +507,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists all channels associated with a specified channel flow.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels_associated_with_channel_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels_associated_with_channel_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channels_associated_with_channel_flow)
         """
 
@@ -506,7 +522,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         A list of the channels moderated by an `AppInstanceUser` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels_moderated_by_app_instance_user)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_channels_moderated_by_app_instance_user)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_channels_moderated_by_app_instance_user)
         """
 
@@ -514,17 +530,33 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Lists the tags applied to an Amazon Chime SDK messaging resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#list_tags_for_resource)
         """
 
+    def put_channel_membership_preferences(
+        self,
+        *,
+        ChannelArn: str,
+        MemberArn: str,
+        ChimeBearer: str,
+        Preferences: "ChannelMembershipPreferencesTypeDef"
+    ) -> PutChannelMembershipPreferencesResponseTypeDef:
+        """
+        Sets the membership preferences of an `AppInstanceUser` for the specified
+        channel.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.put_channel_membership_preferences)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#put_channel_membership_preferences)
+        """
+
     def redact_channel_message(
         self, *, ChannelArn: str, MessageId: str, ChimeBearer: str
     ) -> RedactChannelMessageResponseTypeDef:
         """
         Redacts message content, but not metadata.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.redact_channel_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.redact_channel_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#redact_channel_message)
         """
 
@@ -537,12 +569,14 @@ class ChimeSDKMessagingClient(BaseClient):
         Persistence: ChannelMessagePersistenceTypeType,
         ClientRequestToken: str,
         ChimeBearer: str,
-        Metadata: str = ...
+        Metadata: str = ...,
+        PushNotification: "PushNotificationConfigurationTypeDef" = ...,
+        MessageAttributes: Mapping[str, "MessageAttributeValueTypeDef"] = ...
     ) -> SendChannelMessageResponseTypeDef:
         """
         Sends a message to a particular channel that the member is a part of.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.send_channel_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.send_channel_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#send_channel_message)
         """
 
@@ -550,7 +584,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Applies the specified tags to the specified Amazon Chime SDK messaging resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#tag_resource)
         """
 
@@ -559,7 +593,7 @@ class ChimeSDKMessagingClient(BaseClient):
         Removes the specified tags from the specified Amazon Chime SDK messaging
         resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#untag_resource)
         """
 
@@ -575,7 +609,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Update a channel's attributes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#update_channel)
         """
 
@@ -585,7 +619,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Updates channel flow attributes.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_flow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_flow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#update_channel_flow)
         """
 
@@ -601,7 +635,7 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         Updates the content of a message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_message)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#update_channel_message)
         """
 
@@ -611,6 +645,6 @@ class ChimeSDKMessagingClient(BaseClient):
         """
         The details of the time when a user last read messages in a channel.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_read_marker)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.6/reference/services/chime-sdk-messaging.html#ChimeSDKMessaging.Client.update_channel_read_marker)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_chime_sdk_messaging/client.html#update_channel_read_marker)
         """
