@@ -6,9 +6,9 @@ Type annotations for chime-sdk-messaging service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_chime_sdk_messaging.literals import ChannelMembershipTypeType
+    from mypy_boto3_chime_sdk_messaging.literals import AllowNotificationsType
 
-    data: ChannelMembershipTypeType = "DEFAULT"
+    data: AllowNotificationsType = "ALL"
     ```
 """
 import sys
@@ -20,6 +20,7 @@ else:
 
 
 __all__ = (
+    "AllowNotificationsType",
     "ChannelMembershipTypeType",
     "ChannelMessagePersistenceTypeType",
     "ChannelMessageStatusType",
@@ -29,11 +30,13 @@ __all__ = (
     "ErrorCodeType",
     "FallbackActionType",
     "InvocationTypeType",
+    "PushNotificationTypeType",
     "SortOrderType",
     "ServiceName",
 )
 
 
+AllowNotificationsType = Literal["ALL", "FILTERED", "NONE"]
 ChannelMembershipTypeType = Literal["DEFAULT", "HIDDEN"]
 ChannelMessagePersistenceTypeType = Literal["NON_PERSISTENT", "PERSISTENT"]
 ChannelMessageStatusType = Literal["DENIED", "FAILED", "PENDING", "SENT"]
@@ -59,6 +62,7 @@ ErrorCodeType = Literal[
 ]
 FallbackActionType = Literal["ABORT", "CONTINUE"]
 InvocationTypeType = Literal["ASYNC"]
+PushNotificationTypeType = Literal["DEFAULT", "VOIP"]
 SortOrderType = Literal["ASCENDING", "DESCENDING"]
 ServiceName = Literal[
     "accessanalyzer",
