@@ -13,9 +13,10 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Sequence, Union
+from typing import Any, Dict, List, Mapping, Sequence, Union
 
 from .literals import (
+    AllowNotificationsType,
     ChannelMembershipTypeType,
     ChannelMessagePersistenceTypeType,
     ChannelMessageStatusType,
@@ -24,6 +25,7 @@ from .literals import (
     ChannelPrivacyType,
     ErrorCodeType,
     FallbackActionType,
+    PushNotificationTypeType,
     SortOrderType,
 )
 
@@ -52,6 +54,7 @@ __all__ = (
     "ChannelFlowSummaryTypeDef",
     "ChannelFlowTypeDef",
     "ChannelMembershipForAppInstanceUserSummaryTypeDef",
+    "ChannelMembershipPreferencesTypeDef",
     "ChannelMembershipSummaryTypeDef",
     "ChannelMembershipTypeDef",
     "ChannelMessageCallbackTypeDef",
@@ -94,6 +97,8 @@ __all__ = (
     "DescribeChannelRequestRequestTypeDef",
     "DescribeChannelResponseTypeDef",
     "DisassociateChannelFlowRequestRequestTypeDef",
+    "GetChannelMembershipPreferencesRequestRequestTypeDef",
+    "GetChannelMembershipPreferencesResponseTypeDef",
     "GetChannelMessageRequestRequestTypeDef",
     "GetChannelMessageResponseTypeDef",
     "GetChannelMessageStatusRequestRequestTypeDef",
@@ -121,9 +126,14 @@ __all__ = (
     "ListChannelsResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "MessageAttributeValueTypeDef",
     "MessagingSessionEndpointTypeDef",
     "ProcessorConfigurationTypeDef",
     "ProcessorTypeDef",
+    "PushNotificationConfigurationTypeDef",
+    "PushNotificationPreferencesTypeDef",
+    "PutChannelMembershipPreferencesRequestRequestTypeDef",
+    "PutChannelMembershipPreferencesResponseTypeDef",
     "RedactChannelMessageRequestRequestTypeDef",
     "RedactChannelMessageResponseTypeDef",
     "ResponseMetadataTypeDef",
@@ -309,6 +319,14 @@ ChannelMembershipForAppInstanceUserSummaryTypeDef = TypedDict(
     total=False,
 )
 
+ChannelMembershipPreferencesTypeDef = TypedDict(
+    "ChannelMembershipPreferencesTypeDef",
+    {
+        "PushNotifications": "PushNotificationPreferencesTypeDef",
+    },
+    total=False,
+)
+
 ChannelMembershipSummaryTypeDef = TypedDict(
     "ChannelMembershipSummaryTypeDef",
     {
@@ -374,6 +392,7 @@ ChannelMessageSummaryTypeDef = TypedDict(
         "Sender": "IdentityTypeDef",
         "Redacted": bool,
         "Status": "ChannelMessageStatusStructureTypeDef",
+        "MessageAttributes": Dict[str, "MessageAttributeValueTypeDef"],
     },
     total=False,
 )
@@ -393,6 +412,7 @@ ChannelMessageTypeDef = TypedDict(
         "Redacted": bool,
         "Persistence": ChannelMessagePersistenceTypeType,
         "Status": "ChannelMessageStatusStructureTypeDef",
+        "MessageAttributes": Dict[str, "MessageAttributeValueTypeDef"],
     },
     total=False,
 )
@@ -752,6 +772,25 @@ DisassociateChannelFlowRequestRequestTypeDef = TypedDict(
     },
 )
 
+GetChannelMembershipPreferencesRequestRequestTypeDef = TypedDict(
+    "GetChannelMembershipPreferencesRequestRequestTypeDef",
+    {
+        "ChannelArn": str,
+        "MemberArn": str,
+        "ChimeBearer": str,
+    },
+)
+
+GetChannelMembershipPreferencesResponseTypeDef = TypedDict(
+    "GetChannelMembershipPreferencesResponseTypeDef",
+    {
+        "ChannelArn": str,
+        "Member": "IdentityTypeDef",
+        "Preferences": "ChannelMembershipPreferencesTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetChannelMessageRequestRequestTypeDef = TypedDict(
     "GetChannelMessageRequestRequestTypeDef",
     {
@@ -1127,6 +1166,14 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+MessageAttributeValueTypeDef = TypedDict(
+    "MessageAttributeValueTypeDef",
+    {
+        "StringValues": List[str],
+    },
+    total=False,
+)
+
 MessagingSessionEndpointTypeDef = TypedDict(
     "MessagingSessionEndpointTypeDef",
     {
@@ -1152,6 +1199,56 @@ ProcessorTypeDef = TypedDict(
     },
 )
 
+PushNotificationConfigurationTypeDef = TypedDict(
+    "PushNotificationConfigurationTypeDef",
+    {
+        "Title": str,
+        "Body": str,
+        "Type": PushNotificationTypeType,
+    },
+)
+
+_RequiredPushNotificationPreferencesTypeDef = TypedDict(
+    "_RequiredPushNotificationPreferencesTypeDef",
+    {
+        "AllowNotifications": AllowNotificationsType,
+    },
+)
+_OptionalPushNotificationPreferencesTypeDef = TypedDict(
+    "_OptionalPushNotificationPreferencesTypeDef",
+    {
+        "FilterRule": str,
+    },
+    total=False,
+)
+
+
+class PushNotificationPreferencesTypeDef(
+    _RequiredPushNotificationPreferencesTypeDef, _OptionalPushNotificationPreferencesTypeDef
+):
+    pass
+
+
+PutChannelMembershipPreferencesRequestRequestTypeDef = TypedDict(
+    "PutChannelMembershipPreferencesRequestRequestTypeDef",
+    {
+        "ChannelArn": str,
+        "MemberArn": str,
+        "ChimeBearer": str,
+        "Preferences": "ChannelMembershipPreferencesTypeDef",
+    },
+)
+
+PutChannelMembershipPreferencesResponseTypeDef = TypedDict(
+    "PutChannelMembershipPreferencesResponseTypeDef",
+    {
+        "ChannelArn": str,
+        "Member": "IdentityTypeDef",
+        "Preferences": "ChannelMembershipPreferencesTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 RedactChannelMessageRequestRequestTypeDef = TypedDict(
     "RedactChannelMessageRequestRequestTypeDef",
     {
@@ -1196,6 +1293,8 @@ _OptionalSendChannelMessageRequestRequestTypeDef = TypedDict(
     "_OptionalSendChannelMessageRequestRequestTypeDef",
     {
         "Metadata": str,
+        "PushNotification": "PushNotificationConfigurationTypeDef",
+        "MessageAttributes": Mapping[str, "MessageAttributeValueTypeDef"],
     },
     total=False,
 )
